@@ -2,6 +2,7 @@
 # of the LICENSE file.
 
 import sunlight.service
+from sunlight.errors import BadRequestException
 import json
 
 module_name = "openstates"
@@ -43,6 +44,15 @@ class openstates(sunlight.service.Service):
         """
         return self.get(["bills"], **kwargs)
 
+    def bill(self, bill_id, **kwargs):
+        """
+        Get full information on a single bill from the Open States API given
+        the OpenStates Bill ID (such as TNB00004685)
+
+        `Bill API docs <http://openstates.org/api/bills/>`_.
+        """
+        return self.get(["bills", bill_id], **kwargs)
+
     def bill_detail(self, state, session, bill_id, chamber=None):
         """
         Get full information on a single bill from the Open States API given
@@ -168,6 +178,11 @@ class openstates(sunlight.service.Service):
     # API impl methods
 
     def _get_url(self, objs, apikey, **kwargs):
+        # Gate for any None's in the query. This is usually a problem.
+        if None in objs:
+            raise BadRequestException("`None' passed to the URL encoder (%s)" %
+                                      (str(objs)))
+
         # join pieces by slashes and add a trailing slash
         object_path = "/".join(objs)
         object_path +=  "/"
